theoplayer library
Classes
- AbrAPI
- Dart-side ABR API.
- AbrStrategyConfiguration
- The ABR strategy configuration: type + optional metadata.
- AbrStrategyConfigurationPigeon
- The ABR strategy configuration: type + optional metadata.
- AbrStrategyMetadata
- Metadata for the ABR strategy (e.g. initial bitrate cap).
- AbrStrategyMetadataPigeon
- Metadata for the ABR strategy (e.g. initial bitrate cap).
- AddAudioTrackEvent
- AddTextTrackEvent
- AddVideoTrackEvent
- AndroidConfig
- AndroidTypedSourceConfiguration
- AndroidTypedSourceConfiguration
- AudioActiveQualityChangedEvent
- AudioQualities
- AudioQuality
- AudioQualityEventTypes
- AudioQualityUpdateEvent
- AudioTargetQualityChangedEvent
- AudioTrack
- AudioTrackEventTypes
- AudioTrackListChangeEvent
- AudioTracks
- AudioTracksEventTypes
- CanPlayEvent
- CanPlayThroughEvent
- ChromelessPlayerView
- Cue
- CueEnterEvent
- CueExitEvent
- Cues
- CueUpdateEvent
- CustomWillPopScope
- DateRangeCue
- A cue representing an HLS EXT-X-DATERANGE tag.
- DebugFlag
- Represents a single debug flag with its metadata and current state.
- DebugFlagPigeon
- A single debug flag with its metadata and current state.
- DebugFlagsAPI
- Dart-side wrapper around the Pigeon-generated THEOplayerNativeDebugFlagsAPI.
- DestroyEvent
- DistributionLoadStartEvent
- DistributionOfflineEvent
- DRMConfiguration
- DurationChangeEvent
- EndedEvent
- Endpoint
- EndpointLoadedEvent
- EnterBadNetworkModeEvent
- ErrorEvent
- Event
- ExitBadNetworkModeEvent
- FairPlayDRMConfiguration
- FullscreenConfig
- FullscreenStatefulWidget
- HespLatencies
- IntentToFallbackEvent
- LoadedDataEvent
- LoadedMetadataEvent
- LoadStartEvent
- PauseEvent
- PlayerError
- PlayerEventTypes
- PlayEvent
- PlayingEvent
- PresentationModeAwareWidget
- Internal PresentationMode aware widget to make sure the view is removed from the hierarchy before transitions are happening. Android and Web are ok, but iOS doesn't remove the view in time when switching between presentation modes.
- PresentationModeChangeEvent
- ProgressEvent
- RateChangeEvent
- ReadyStateChangeEvent
- RemoveAudioTrackEvent
- RemoveTextTrackEvent
- RemoveVideoTrackEvent
- ResizeEvent
- SeekedEvent
- SeekingEvent
- SourceChangeEvent
- SourceDescription
- TextTrack
- Represents a text track of a media resource.
- TextTrackAddCueEvent
- TextTrackChangeEvent
- TextTrackCueChangeEvent
- TextTrackCueEventTypes
- TextTrackEnterCueEvent
- TextTrackEventTypes
- TextTrackExitCueEvent
- TextTrackListChangeEvent
- TextTrackRemoveCueEvent
- TextTracks
- TextTracksEventTypes
- THEOlive
- THEOliveApiEventTypes
- TheoLiveConfiguration
- TheoLiveSource
- THEOlive TypedSource
- THEOplayer
- Class to initialize and interact with THEOplayer
- THEOplayerConfig
- THEOplayerFlutterAPI
- THEOplayerFlutterAudioTracksAPI
- THEOplayerFlutterTextTracksAPI
- THEOplayerFlutterTHEOliveAPI
- THEOplayerFlutterVideoTracksAPI
- THEOplayerNativeAbrAPI
- Host API: Dart → Native calls for ABR configuration.
- THEOplayerNativeAPI
- THEOplayerNativeAudioTracksAPI
- THEOplayerNativeDebugFlagsAPI
- Host API: Dart → Native calls for debug flag management.
- THEOplayerNativeTextTracksAPI
- THEOplayerNativeTHEOliveAPI
- THEOplayerNativeVideoTracksAPI
- THEOplayerViewController
- TimeRange
- TimeUpdateEvent
- TypedSource
- TypedSource
- TypedSourcePigeon
- Internal TypedSource Pigeon for Android/iOS communication Remarks:
- VideoActiveQualityChangedEvent
- VideoQualities
- VideoQuality
- VideoQualityEventTypes
- VideoQualityUpdateEvent
- VideoTargetQualityChangedEvent
- VideoTrack
- VideoTrackEventTypes
- VideoTrackListChangeEvent
- VideoTracks
- VideoTracksEventTypes
- VolumeChangeEvent
- WaitingEvent
- WebConfig
- WidevineDRMConfiguration
Enums
- AbrStrategyType
- The adaptive bitrate strategy type.
- AbrStrategyTypePigeon
- The adaptive bitrate strategy type.
- AndroidViewComposition
- https://github.com/flutter/flutter/wiki/Android-Platform-Views TODO: move to pigeons
- DistributionState
- PreloadType
- PresentationMode
- ReadyState
- SourceIntegrationId
- TextTrackMode
- TextTrackReadyState
- TextTrackType
Functions
-
wrapResponse(
{Object? result, PlatformException? error, bool empty = false}) → List< Object?>
Typedefs
- AutomaticFullscreenExitListener = void Function()
- FullscreenWidgetBuilder = Widget Function(BuildContext context, THEOplayer theoplayer)
- Signature for a function that builds a fullscreen widget given an THEOplayer.
- PlayerCreatedCallback = void Function()
- Callback that's used at player creation. This is called once the underlying native THEOplayerView is fully created and available to use.
- StateChangeListener = void Function()
- Callback that's triggered every time the internal player state is changing. See THEOplayer.setStateListener.
- THEOliveStateChangeListener = void Function()
- Callback that's triggered every time the internal player state is changing. See THEOplayer.setStateListener.