THEOplayerFlutterTHEOliveAPI class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDistributionLoadStartEvent(String distributionId) → void
onDistributionOfflineEvent(String distributionId) → void
onEndpointLoadedEvent(Endpoint endpoint) → void
onIntentToFallbackEvent(String? errorCode, String? errorMessage) → void
onSeeked(double currentTime) → void
onSeeking(double currentTime) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

setUp(THEOplayerFlutterTHEOliveAPI? api, {BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''}) → void

Constants

pigeonChannelCodec → const MessageCodec<Object?>